Annotation Type Fluent


  • @Retention(RUNTIME)
    @Target(METHOD)
    public @interface Fluent
    Declares a fluent method return type when the method returns the type of the class declaring this method or a sub type.