Annotation Type GenIgnore


  • @Retention(RUNTIME)
    public @interface GenIgnore
    The annotated element is ignored by the code generator, this can be used to provide Java exclusive methods that are not compatible with the vertx codegen rules.
    Author:
    Tim Fox
    • Optional Element Summary

      Optional Elements 
      Modifier and Type Optional Element Description
      String[] value  
    • Field Detail

      • PERMITTED_TYPE

        static final String PERMITTED_TYPE
    • Element Detail

      • value

        String[] value
        Default:
        {}