Annotation Type ProxyGen


  • @Retention(RUNTIME)
    @Target(TYPE)
    public @interface ProxyGen
    Declares a Java interface type to be processed for generating a Java proxy that can be connected to the original API via Vert.x event bus.
    Author:
    Tim Fox