Module io.vertx.codegen.api
Package io.vertx.codegen.annotations
-
Annotation Types Summary Annotation Type Description CacheReturn Declares that the value returned by a method will always be the same.DataObject Declares a data object, such object must provide at least: a constructor withio.vertx.core.json.JsonObjectFluent Declares a fluent method return type when the method returns the type of the class declaring this method or a sub type.GenIgnore The annotated element is ignored by the code generator, this can be used to provide Java exclusive methods that are not compatible with the vertx codegen rules.ModuleGen Declares a Codegen module, all the processed elements contained in the annotated package or one of its child package will be part of the same module.Nullable ProxyClose Declares a proxy close method.ProxyGen Declares a Java interface type to be processed for generating a Java proxy that can be connected to the original API via Vert.x event bus.ProxyIgnore The annotated element is ignored by the proxy generator, this can be used to provide Java exclusive methods that are not compatible with the proxy codegen rules.Unstable Indicates a Vert.x public API element is subject to change (e.g. type/name modification or removal).VertxGen Declares a Java interface type to be processed for creating API in various languages of polyglot Vert.x.