Class Case

    • Constructor Detail

      • Case

        public Case()
    • Method Detail

      • parse

        public List<String> parse​(String name)
        Parse the name argument and returns a list of the name atoms.
        Parameters:
        name - the name to parse
        Returns:
        the name atoms
        Throws:
        IllegalArgumentException - if the name has a syntax error
      • to

        public String to​(Case dest,
                         String name)
        Convert a name from this case to the dest case
        Parameters:
        dest - the destination case
        name - the name to convert
        Returns:
        the converted name
      • vars

        public static Map<String,​Case> vars()
        Useful for formatting or parsing string, eg:CASE_CAMEL.format(CASE_SNAKE.parse("foo_bar")),it will return fooBar