Uses of Class
io.vertx.codegen.format.Case
-
Packages that use Case Package Description io.vertx.codegen.format -
-
Uses of Case in io.vertx.codegen.format
Subclasses of Case in io.vertx.codegen.format Modifier and Type Class Description classCamelCaseCamel case, for instance FooBar.classKebabCaseKebab case, for instance foo-bar.classLowerCamelCaseCamel case starting with a lower case, for instance fooBar.classQualifiedCaseJava full qualified case, for instance foo.barclassSnakeCaseSnake case, for instance foo_bar.Fields in io.vertx.codegen.format declared as Case Modifier and Type Field Description static CaseCamelCase. INSTANCEACamelCaseinstance.static CaseKebabCase. INSTANCEACamelCaseinstance.static CaseLowerCamelCase. INSTANCEALowerCamelCaseinstance.static CaseQualifiedCase. INSTANCEAQualifiedCaseinstance.static CaseSnakeCase. INSTANCEASnakeCaseinstance.Methods in io.vertx.codegen.format that return types with arguments of type Case Modifier and Type Method Description static Map<String,Case>Case. vars()Useful for formatting or parsing string, eg:CASE_CAMEL.format(CASE_SNAKE.parse("foo_bar")),it will return fooBarMethods in io.vertx.codegen.format with parameters of type Case Modifier and Type Method Description StringCase. to(Case dest, String name)Convert a name from this case to the dest case
-