JavaScript is disabled on your browser.
Skip navigation links
Module
Package
Class
Use
Tree
Deprecated
Index
Help
All Classes
SEARCH:
JavaScript is disabled on your browser.
Summary:
Field |
Required |
Optional
Detail:
Field |
Element
Module
io.vertx.codegen.api
Package
io.vertx.codegen.annotations
Annotation Type Fluent
@Retention
(
RUNTIME
)
@Target
(
METHOD
) public @interface
Fluent
Declares a fluent method return type when the method returns the type of the class declaring this method or a sub type.