-
@Retention(RUNTIME) public @interface GenIgnore
The annotated element is ignored by the code generator, this can be used to provide Java exclusive methods that are not compatible with the vertx codegen rules.- Author:
- Tim Fox
-
-
Field Summary
Fields Modifier and Type Fields Description static StringPERMITTED_TYPE
-