-
@Retention(RUNTIME) public @interface ProxyIgnore
The annotated element is ignored by the proxy generator, this can be used to provide Java exclusive methods that are not compatible with the proxy codegen rules.- Author:
- Tim Fox
@Retention(RUNTIME) public @interface ProxyIgnore