-
@Retention(RUNTIME) @Target(TYPE) public @interface VertxGen
Declares a Java interface type to be processed for creating API in various languages of polyglot Vert.x.- Author:
- Tim Fox
-
-
Optional Element Summary
Optional Elements Modifier and Type Optional Element Description booleanconcrete
-
-
-
Element Detail
-
concrete
boolean concrete
- Returns:
truewhen the annotated interface is considered to be implemented by a class in the generated code base, when an interface is not concrete it is an abstract interface. An abstract interface cannot extend a concrete interface, a concrete interface can extend at most two concrete interfaces.
- Default:
- true
-
-